import * as wijmo from '@mescius/wijmo';
import * as grid from '@mescius/wijmo.grid';
import * as pdf from '@mescius/wijmo.pdf';
import * as gridPdf from '@mescius/wijmo.grid.pdf';

import { Component, Inject, ViewChild } from '@angular/core';
import { DataService } from './app.data';
import { WjGridModule } from '@mescius/wijmo.angular2.grid';

@Component({
  selector: 'app-root',
  standalone: true,
  imports: [WjGridModule],
  templateUrl: './app.component.html',
  styleUrl: './app.component.scss'
})
export class AppComponent {
  data: any[];
  @ViewChild('flexGrid', { static: true }) flexGrid?: grid.FlexGrid;
  //
  constructor(@Inject(DataService) private dataService: DataService) {
      this.data = dataService.getData(10);
  }
  //
  export() {
      let doc = new pdf.PdfDocument({
          header: {
              declarative: {
                  text: '\t&[Page]\\&[Pages]'
              }
          },
          footer: {
              declarative: {
                  text: '\t&[Page]\\&[Pages]'
              }
          },
          ended: (sender: pdf.PdfDocument, args: pdf.PdfDocumentEndedEventArgs) => pdf.saveBlob(args.blob, 'FlexGrid.pdf')
      });
      //
      let settings = {
          styles: {
              cellStyle: {
                  backgroundColor: '#ffffff',
                  borderColor: '#c6c6c6'
              },
              altCellStyle: {
                  backgroundColor: '#f9f9f9'
              },
              groupCellStyle: {
                  backgroundColor: '#dddddd'
              },
              headerCellStyle: {
                  backgroundColor: '#eaeaea'
              }
          }
      };
      //
      doc.drawText('This grid is scaled to fit the width of 200 and drawn using the draw method.', undefined, undefined, { width: 200 });
      doc.moveDown();
      gridPdf.FlexGridPdfConverter.draw(this.flexGrid, doc, 200, undefined, settings);
      //
      doc.drawText('This grid is drawn in its original size using the drawToPosition method.', 220, 0);
      doc.moveDown();
      gridPdf.FlexGridPdfConverter.drawToPosition(this.flexGrid, doc, new wijmo.Point(220, doc.y), undefined, undefined, settings);
      //
      doc.drawText('This grid is drawn in its original size using the draw method and is split into multiple pages.', 0, 400);
      doc.moveDown();
      gridPdf.FlexGridPdfConverter.draw(this.flexGrid, doc, undefined, undefined, settings);
      //
      doc.end();
  }
}
